from .http import vrt_api_request


def traffic_teaser():
    res = vrt_api_request(
        "traffic",
        "teaser",
        params={"accept": "application/vnd.traffic.vrt.be.teaser_1.0+json"},
    )
    return res


def traffic_jam(km=False):
    traffic_data = traffic_teaser()

    if traffic_data and traffic_data.get("teaser"):
        traffic_jam_length = traffic_data["teaser"]["trafficJamLength"]
        if km:
            return {"length": traffic_jam_length / 1000, "unit": "km"}
        else:
            return {"length": traffic_jam_length, "unit": "m"}
    else:
        return {}



import requests

BASE_URL = "https://services.vrt.be/{}/{}"


def vrt_api_request(service, path, params=None):
    url = BASE_URL.format(service, path)

    try:
        res = requests.get(url, params)
        try:
            json_res = res.json()
            return json_res
        except ValueError:
            return None

    except requests.RequestException as ex:
        print("Failed to do VRT API request:", ex)
        return None



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pyvrt",
    version="1.6.2",
    author="thibmaek",
    author_email="thibault.maekelbergh@icloud.com",
    description="Python library to interact with VRT public APIs",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/thibmaek/pyvrt",
    packages=setuptools.find_packages(),
    install_requires=['requests'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6'
)



from .http import vrt_api_request


def __get_zone_from_list(items_list, zone):
    try:
        res = filter(lambda item: item["location"].lower() == zone.lower(), items_list)
        return res
    except (KeyError, StopIteration) as ex:
        raise ValueError("Could not find zone in list", ex, items_list)


def summary(region="BE"):
    if region != "BE":
        raise ValueError("Only region=BE is supported for retrieving summary")

    res = vrt_api_request(
        "weather",
        "weathertalks/belgie_huidig",
        params={"accept": "application/vnd.weather.vrt.be.weathertalks_1.0+json"},
    )

    if res:
        return res["weathertalk"]
    else:
        return None


def current(region="BE", zone=None):
    if region == "BE":
        res = vrt_api_request(
            "weather",
            "observations/belgische_streken",
            params={"accept": "application/vnd.weather.vrt.be.observations_1.0+json"},
        )

    if zone:
        zone_res = next(__get_zone_from_list(res["observations"], zone))
        zone_res["date"] = res["date"]
        return zone_res

    return res

    if region == "EU":
        res = vrt_api_request(
            "weather",
            "observations/europese_steden",
            params={"accept": "application/vnd.weather.vrt.be.observations_1.0+json"},
        )

    if zone:
        zone_res = next(__get_zone_from_list(res["observations"], zone))
        zone_res["date"] = res["date"]
        return zone_res
    else:
        return res


def forecast(region="BE", zone=None):
    if region == "BE":
        res = vrt_api_request(
            "weather",
            "forecasts/belgische_streken",
            params={"accept": "application/vnd.weather.vrt.be.forecasts_1.0+json"},
        )

        if zone:
            return {
                "date": res["date"],
                "forecasts": list(__get_zone_from_list(res["forecasts"], zone)),
            }
        else:
            return res

    if region == "EU":
        res = vrt_api_request(
            "weather",
            "forecasts/europese_steden",
            params={"accept": "application/vnd.weather.vrt.be.forecasts_1.0+json"},
        )

        if zone:
            return {
                "date": res["date"],
                "forecasts": list(__get_zone_from_list(res["forecasts"], zone)),
            }
        else:
            return res
